@@ -5,6 +5,10 @@ import pandas as pd
 import os
 import csv
 import json
+import pytz
+import datetime
+import dateutil
+import random
 
 
 class mos():
@@ -14,6 +18,19 @@ class mos():
         if not os.path.exists(data_dir):
             os.makedirs(data_dir)
 
+    def get_file_list(path):
+        for root, dirs, files in os.walk(path):
+            pass
+        return files
+
+
+class mtime():
+    def get_iso_time():
+        utc_tz = pytz.timezone('Asia/Shanghai')
+        datestr = datetime.datetime.now(tz=utc_tz).isoformat()
+        mydatetime = dateutil.parser.parse(datestr)
+        return mydatetime
+
 
 class mstring():
 
@@ -60,9 +77,31 @@ class mstring():
     def nbsp2space(s):
         return s.replace('\xa0', ' ')
 
+    def get_random_36(n):
+        randomStr = ""
+        for i in range(n):
+            temp = random.randrange(0, 3)
+            if temp == 0:
+                ch = chr(random.randrange(ord('A'), ord('Z') + 1))
+                randomStr += ch
+            elif temp == 1:
+                ch = chr(random.randrange(ord('a'), ord('z') + 1))
+                randomStr += ch
+            else:
+                ch = str((random.randrange(0, 10)))
+                randomStr += ch
+        return randomStr
+
 
 class mlist():
 
+    def get_cols(data_list):
+        columns = []
+        if len(data_list) > 0:
+            first = data_list[0]
+            columns = list(first.keys())
+        return columns
+
     def from_csv(path, options):
         with open(path, 'r', encoding='utf-8-sig')as f:
             reader = csv.DictReader(f)
@@ -80,6 +119,15 @@ class mlist():
         result_list = pd.DataFrame(columns=columns, data=data_list)
         result_list.to_csv(path, encoding='utf-8-sig', index=False)
 
+    def from_excel(path, sheet_name):
+        temp_df = pd.read_excel(path, sheet_name=sheet_name, dtype=str)
+        data_list = list(temp_df.to_dict('records'))
+        return data_list
+
+    def to_excel(data_list, columns, path):
+        result_list = pd.DataFrame(columns=columns, data=data_list)
+        result_list.to_excel(path, encoding='utf-8-sig', index=False)
+
     def from_json(path):
         with open(path, 'r', encoding='utf-8-sig') as f:
             pre_data_list = json.load(f)
